Item Processor
==============

Class which process input push items and based on their metadata produce various information
needed for the push process.

.. py.module pubtools._quay.item_processor

.. autoclass:: SignEntry
    :members:

.. autoclass:: ManifestArchDigest
    :members:

.. autoclass:: ContentExtractor
    :members:

.. autoclass:: ReferenceProcessorInternal
    :members:

.. autoclass:: ReferenceProcessorExternal
    :members:

.. autoclass ItemProcessor
    :members:

"""
